import json

__title__ = 'safety-db'
__version__ = '2018.7.24'
__author__ = 'Justin Womersley <support@pyup.io>'
__copyright__ = '2016-2017 PyUp'
__license__ = 'Attribution-NonCommercial-ShareAlike 4.0 International'
__all__ = (
    'INSECURE',
    'INSECURE_FULL',
)

with open("data/insecure.json") as __f:
    try:
        INSECURE = json.loads(__f.read())
    except ValueError as e:
        INSECURE = []


with open("data/insecure_full.json") as __f:
    try:
        INSECURE_FULL = json.loads(__f.read())
    except ValueError as e:
        INSECURE_FULL = []



import os

from setuptools import setup

from safety_db import __version__ as version

try:
    readme = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()
except:
    readme = ''

tests_require = [
    'packaging',
]

setup(
    name='safety-db',
    version=version,
    description="A curated database of insecure Python packages",
    long_description=readme,
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
    ],
    keywords="security",
    author='Jannis Gebauer',
    author_email='support@pyup.io',
    url='https://github.com/pyupio/safety-db/',
    py_modules=['safety_db'],
    license='Attribution-NonCommercial-ShareAlike 4.0 International',
    install_requires=[],
    tests_require=tests_require,
    include_package_data=True,
)
